==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-accumulation-distribution-indicator.js <==
import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { AccumulationDistributionIndicator } from "./AccumulationDistributionIndicator";
/**
 * Represents a IgxDataChartComponent Accumulation/Distribution indicator series.
 * Default required members: Close, Low, High, Volume
*
* You can use the `IgxAccumulationDistributionIndicatorComponent` to evaluate the suppy and demand of a stock, security, or index.
*
* ```html
* <igx-data-chart
* 	#chart
*     [dataSource]="data" >
*     <igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
*     <igx-accumulation-distribution-indicator
* 		[xAxis]="xAxis"
* 		[yAxis]="yAxis"
* 		openMemberPath="open"
* 		highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close">
*     </igx-accumulation-distribution-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxAccumulationDistributionIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
var IgrAccumulationDistributionIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(IgrAccumulationDistributionIndicator, _super);
    function IgrAccumulationDistributionIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrAccumulationDistributionIndicator.prototype.createImplementation = function () {
        return new AccumulationDistributionIndicator();
    };
    Object.defineProperty(IgrAccumulationDistributionIndicator.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    return IgrAccumulationDistributionIndicator;
}(IgrStrategyBasedIndicator));
export { IgrAccumulationDistributionIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-accumulation-distribution-indicator.js <==
import * as tslib_1 from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { AccumulationDistributionIndicator } from "./AccumulationDistributionIndicator";
/**
 * Represents a IgxDataChartComponent Accumulation/Distribution indicator series.
 * Default required members: Close, Low, High, Volume
*
* You can use the `IgrAccumulationDistributionIndicator` to evaluate the suppy and demand of a stock, security, or index.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*
*     <IgrCategoryXAxis name="xAxis" label="Date" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrAccumulationDistributionIndicator
* 	name="series1"
* 	xAxisName="xAxis"
*     yAxisName="yAxis"
*     displayType="Line"
*     lowMemberPath="Low"
*     highMemberPath="High"
*     openMemberPath="Open"
*     closeMemberPath="Close"
*     volumeMemberPath="Volume"/>
*  </IgrDataChart>
* ```
*/
var IgrAccumulationDistributionIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(IgrAccumulationDistributionIndicator, _super);
    function IgrAccumulationDistributionIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrAccumulationDistributionIndicator.prototype.createImplementation = function () {
        return new AccumulationDistributionIndicator();
    };
    Object.defineProperty(IgrAccumulationDistributionIndicator.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    return IgrAccumulationDistributionIndicator;
}(IgrStrategyBasedIndicator));
export { IgrAccumulationDistributionIndicator };
